Class: Google::Apis::PolicysimulatorV1beta::GoogleCloudPolicysimulatorV1betaAccessStateDiff

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/policysimulator_v1beta/classes.rb,
lib/google/apis/policysimulator_v1beta/representations.rb,
lib/google/apis/policysimulator_v1beta/representations.rb

Overview

A summary and comparison of the principal's access under the current (baseline) policies and the proposed (simulated) policies for a single access tuple.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudPolicysimulatorV1betaAccessStateDiff

Returns a new instance of GoogleCloudPolicysimulatorV1betaAccessStateDiff.



551
552
553
# File 'lib/google/apis/policysimulator_v1beta/classes.rb', line 551

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#access_changeString

How the principal's access, specified in the AccessState field, changed between the current (baseline) policies and proposed (simulated) policies. Corresponds to the JSON property accessChange

Returns:

  • (String)


537
538
539
# File 'lib/google/apis/policysimulator_v1beta/classes.rb', line 537

def access_change
  @access_change
end

#baselineGoogle::Apis::PolicysimulatorV1beta::GoogleCloudPolicysimulatorV1betaExplainedAccess

Details about how a set of policies, listed in ExplainedPolicy, resulted in a certain AccessState when replaying an access tuple. Corresponds to the JSON property baseline



543
544
545
# File 'lib/google/apis/policysimulator_v1beta/classes.rb', line 543

def baseline
  @baseline
end

#simulatedGoogle::Apis::PolicysimulatorV1beta::GoogleCloudPolicysimulatorV1betaExplainedAccess

Details about how a set of policies, listed in ExplainedPolicy, resulted in a certain AccessState when replaying an access tuple. Corresponds to the JSON property simulated



549
550
551
# File 'lib/google/apis/policysimulator_v1beta/classes.rb', line 549

def simulated
  @simulated
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



556
557
558
559
560
# File 'lib/google/apis/policysimulator_v1beta/classes.rb', line 556

def update!(**args)
  @access_change = args[:access_change] if args.key?(:access_change)
  @baseline = args[:baseline] if args.key?(:baseline)
  @simulated = args[:simulated] if args.key?(:simulated)
end