Class: Google::Apis::PolicysimulatorV1beta::GoogleCloudPolicysimulatorV1betaListOrgPolicyViolationsPreviewsResponse
- Inherits:
-
Object
- Object
- Google::Apis::PolicysimulatorV1beta::GoogleCloudPolicysimulatorV1betaListOrgPolicyViolationsPreviewsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/policysimulator_v1beta/classes.rb,
lib/google/apis/policysimulator_v1beta/representations.rb,
lib/google/apis/policysimulator_v1beta/representations.rb
Overview
ListOrgPolicyViolationsPreviewsResponse is the response message for OrgPolicyViolationsPreviewService.ListOrgPolicyViolationsPreviews.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A token that you can use to retrieve the next page of results.
-
#org_policy_violations_previews ⇒ Array<Google::Apis::PolicysimulatorV1beta::GoogleCloudPolicysimulatorV1betaOrgPolicyViolationsPreview>
The list of OrgPolicyViolationsPreview Corresponds to the JSON property
orgPolicyViolationsPreviews.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudPolicysimulatorV1betaListOrgPolicyViolationsPreviewsResponse
constructor
A new instance of GoogleCloudPolicysimulatorV1betaListOrgPolicyViolationsPreviewsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudPolicysimulatorV1betaListOrgPolicyViolationsPreviewsResponse
Returns a new instance of GoogleCloudPolicysimulatorV1betaListOrgPolicyViolationsPreviewsResponse.
962 963 964 |
# File 'lib/google/apis/policysimulator_v1beta/classes.rb', line 962 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A token that you can use to retrieve the next page of results. If this field
is omitted, there are no subsequent pages.
Corresponds to the JSON property nextPageToken
955 956 957 |
# File 'lib/google/apis/policysimulator_v1beta/classes.rb', line 955 def next_page_token @next_page_token end |
#org_policy_violations_previews ⇒ Array<Google::Apis::PolicysimulatorV1beta::GoogleCloudPolicysimulatorV1betaOrgPolicyViolationsPreview>
The list of OrgPolicyViolationsPreview
Corresponds to the JSON property orgPolicyViolationsPreviews
960 961 962 |
# File 'lib/google/apis/policysimulator_v1beta/classes.rb', line 960 def org_policy_violations_previews @org_policy_violations_previews end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
967 968 969 970 |
# File 'lib/google/apis/policysimulator_v1beta/classes.rb', line 967 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @org_policy_violations_previews = args[:org_policy_violations_previews] if args.key?(:org_policy_violations_previews) end |