Class: Google::Apis::PolicysimulatorV1beta::GoogleCloudPolicysimulatorV1betaListOrgPolicyViolationsResponse
- Inherits:
-
Object
- Object
- Google::Apis::PolicysimulatorV1beta::GoogleCloudPolicysimulatorV1betaListOrgPolicyViolationsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/policysimulator_v1beta/classes.rb,
lib/google/apis/policysimulator_v1beta/representations.rb,
lib/google/apis/policysimulator_v1beta/representations.rb
Overview
ListOrgPolicyViolationsResponse is the response message for OrgPolicyViolationsPreviewService.ListOrgPolicyViolations
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A token that you can use to retrieve the next page of results.
-
#org_policy_violations ⇒ Array<Google::Apis::PolicysimulatorV1beta::GoogleCloudPolicysimulatorV1betaOrgPolicyViolation>
The list of OrgPolicyViolations Corresponds to the JSON property
orgPolicyViolations.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudPolicysimulatorV1betaListOrgPolicyViolationsResponse
constructor
A new instance of GoogleCloudPolicysimulatorV1betaListOrgPolicyViolationsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudPolicysimulatorV1betaListOrgPolicyViolationsResponse
Returns a new instance of GoogleCloudPolicysimulatorV1betaListOrgPolicyViolationsResponse.
989 990 991 |
# File 'lib/google/apis/policysimulator_v1beta/classes.rb', line 989 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A token that you can use to retrieve the next page of results. If this field
is omitted, there are no subsequent pages.
Corresponds to the JSON property nextPageToken
982 983 984 |
# File 'lib/google/apis/policysimulator_v1beta/classes.rb', line 982 def next_page_token @next_page_token end |
#org_policy_violations ⇒ Array<Google::Apis::PolicysimulatorV1beta::GoogleCloudPolicysimulatorV1betaOrgPolicyViolation>
The list of OrgPolicyViolations
Corresponds to the JSON property orgPolicyViolations
987 988 989 |
# File 'lib/google/apis/policysimulator_v1beta/classes.rb', line 987 def org_policy_violations @org_policy_violations end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
994 995 996 997 |
# File 'lib/google/apis/policysimulator_v1beta/classes.rb', line 994 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @org_policy_violations = args[:org_policy_violations] if args.key?(:org_policy_violations) end |