Class: Google::Apis::PolicysimulatorV1beta::GoogleCloudPolicysimulatorV1betaListReplayResultsResponse
- Inherits:
-
Object
- Object
- Google::Apis::PolicysimulatorV1beta::GoogleCloudPolicysimulatorV1betaListReplayResultsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/policysimulator_v1beta/classes.rb,
lib/google/apis/policysimulator_v1beta/representations.rb,
lib/google/apis/policysimulator_v1beta/representations.rb
Overview
Response message for Simulator.ListReplayResults.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A token that you can use to retrieve the next page of ReplayResult objects.
-
#replay_results ⇒ Array<Google::Apis::PolicysimulatorV1beta::GoogleCloudPolicysimulatorV1betaReplayResult>
The results of running a Replay.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudPolicysimulatorV1betaListReplayResultsResponse
constructor
A new instance of GoogleCloudPolicysimulatorV1betaListReplayResultsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudPolicysimulatorV1betaListReplayResultsResponse
Returns a new instance of GoogleCloudPolicysimulatorV1betaListReplayResultsResponse.
1015 1016 1017 |
# File 'lib/google/apis/policysimulator_v1beta/classes.rb', line 1015 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A token that you can use to retrieve the next page of ReplayResult objects. If
this field is omitted, there are no subsequent pages.
Corresponds to the JSON property nextPageToken
1008 1009 1010 |
# File 'lib/google/apis/policysimulator_v1beta/classes.rb', line 1008 def next_page_token @next_page_token end |
#replay_results ⇒ Array<Google::Apis::PolicysimulatorV1beta::GoogleCloudPolicysimulatorV1betaReplayResult>
The results of running a Replay.
Corresponds to the JSON property replayResults
1013 1014 1015 |
# File 'lib/google/apis/policysimulator_v1beta/classes.rb', line 1013 def replay_results @replay_results end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1020 1021 1022 1023 |
# File 'lib/google/apis/policysimulator_v1beta/classes.rb', line 1020 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @replay_results = args[:replay_results] if args.key?(:replay_results) end |