Class: Google::Apis::PolicysimulatorV1beta::GoogleCloudPolicysimulatorV1betaListReplaysResponse
- Inherits:
-
Object
- Object
- Google::Apis::PolicysimulatorV1beta::GoogleCloudPolicysimulatorV1betaListReplaysResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/policysimulator_v1beta/classes.rb,
lib/google/apis/policysimulator_v1beta/representations.rb,
lib/google/apis/policysimulator_v1beta/representations.rb
Overview
Response message for Simulator.ListReplays.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A token that you can use to retrieve the next page of results.
-
#replays ⇒ Array<Google::Apis::PolicysimulatorV1beta::GoogleCloudPolicysimulatorV1betaReplay>
The list of Replay objects.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudPolicysimulatorV1betaListReplaysResponse
constructor
A new instance of GoogleCloudPolicysimulatorV1betaListReplaysResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudPolicysimulatorV1betaListReplaysResponse
Returns a new instance of GoogleCloudPolicysimulatorV1betaListReplaysResponse.
1041 1042 1043 |
# File 'lib/google/apis/policysimulator_v1beta/classes.rb', line 1041 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A token that you can use to retrieve the next page of results. If this field
is omitted, there are no subsequent pages.
Corresponds to the JSON property nextPageToken
1034 1035 1036 |
# File 'lib/google/apis/policysimulator_v1beta/classes.rb', line 1034 def next_page_token @next_page_token end |
#replays ⇒ Array<Google::Apis::PolicysimulatorV1beta::GoogleCloudPolicysimulatorV1betaReplay>
The list of Replay objects.
Corresponds to the JSON property replays
1039 1040 1041 |
# File 'lib/google/apis/policysimulator_v1beta/classes.rb', line 1039 def replays @replays end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1046 1047 1048 1049 |
# File 'lib/google/apis/policysimulator_v1beta/classes.rb', line 1046 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @replays = args[:replays] if args.key?(:replays) end |