Class: Google::Apis::PolicysimulatorV1beta::GoogleCloudPolicysimulatorV1betaOrgPolicyOverlay

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/policysimulator_v1beta/classes.rb,
lib/google/apis/policysimulator_v1beta/representations.rb,
lib/google/apis/policysimulator_v1beta/representations.rb

Overview

The proposed changes to OrgPolicy.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudPolicysimulatorV1betaOrgPolicyOverlay

Returns a new instance of GoogleCloudPolicysimulatorV1betaOrgPolicyOverlay.



1075
1076
1077
# File 'lib/google/apis/policysimulator_v1beta/classes.rb', line 1075

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#custom_constraintsArray<Google::Apis::PolicysimulatorV1beta::GoogleCloudPolicysimulatorV1betaOrgPolicyOverlayCustomConstraintOverlay>

Optional. The OrgPolicy CustomConstraint changes to preview violations for. Any existing CustomConstraints with the same name will be overridden in the simulation. That is, violations will be determined as if all custom constraints in the overlay were instantiated. Only a single custom_constraint is supported in the overlay at a time. For evaluating multiple constraints, multiple GenerateOrgPolicyViolationsPreview requests are made, where each request evaluates a single constraint. Corresponds to the JSON property customConstraints



1065
1066
1067
# File 'lib/google/apis/policysimulator_v1beta/classes.rb', line 1065

def custom_constraints
  @custom_constraints
end

#policiesArray<Google::Apis::PolicysimulatorV1beta::GoogleCloudPolicysimulatorV1betaOrgPolicyOverlayPolicyOverlay>

Optional. The OrgPolicy changes to preview violations for. Any existing OrgPolicies with the same name will be overridden in the simulation. That is, violations will be determined as if all policies in the overlay were created or updated. Corresponds to the JSON property policies



1073
1074
1075
# File 'lib/google/apis/policysimulator_v1beta/classes.rb', line 1073

def policies
  @policies
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1080
1081
1082
1083
# File 'lib/google/apis/policysimulator_v1beta/classes.rb', line 1080

def update!(**args)
  @custom_constraints = args[:custom_constraints] if args.key?(:custom_constraints)
  @policies = args[:policies] if args.key?(:policies)
end