Class: Google::Apis::PolicysimulatorV1beta::GoogleCloudPolicysimulatorV1betaOrgPolicyOverlayPolicyOverlay
- Inherits:
-
Object
- Object
- Google::Apis::PolicysimulatorV1beta::GoogleCloudPolicysimulatorV1betaOrgPolicyOverlayPolicyOverlay
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/policysimulator_v1beta/classes.rb,
lib/google/apis/policysimulator_v1beta/representations.rb,
lib/google/apis/policysimulator_v1beta/representations.rb
Overview
A change to an OrgPolicy.
Instance Attribute Summary collapse
-
#policy ⇒ Google::Apis::PolicysimulatorV1beta::GoogleCloudOrgpolicyV2Policy
Defines an organization policy that is used to specify constraints for configurations of Google Cloud resources.
-
#policy_parent ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudPolicysimulatorV1betaOrgPolicyOverlayPolicyOverlay
constructor
A new instance of GoogleCloudPolicysimulatorV1betaOrgPolicyOverlayPolicyOverlay.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudPolicysimulatorV1betaOrgPolicyOverlayPolicyOverlay
Returns a new instance of GoogleCloudPolicysimulatorV1betaOrgPolicyOverlayPolicyOverlay.
1131 1132 1133 |
# File 'lib/google/apis/policysimulator_v1beta/classes.rb', line 1131 def initialize(**args) update!(**args) end |
Instance Attribute Details
#policy ⇒ Google::Apis::PolicysimulatorV1beta::GoogleCloudOrgpolicyV2Policy
Defines an organization policy that is used to specify constraints for
configurations of Google Cloud resources.
Corresponds to the JSON property policy
1123 1124 1125 |
# File 'lib/google/apis/policysimulator_v1beta/classes.rb', line 1123 def policy @policy end |
#policy_parent ⇒ String
Optional. The parent of the policy we are attaching to. Example: "projects/
123456"
Corresponds to the JSON property policyParent
1129 1130 1131 |
# File 'lib/google/apis/policysimulator_v1beta/classes.rb', line 1129 def policy_parent @policy_parent end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1136 1137 1138 1139 |
# File 'lib/google/apis/policysimulator_v1beta/classes.rb', line 1136 def update!(**args) @policy = args[:policy] if args.key?(:policy) @policy_parent = args[:policy_parent] if args.key?(:policy_parent) end |