Class: Google::Apis::PolicysimulatorV1beta::GoogleCloudPolicysimulatorV1betaOrgPolicyViolationsPreview
- Inherits:
-
Object
- Object
- Google::Apis::PolicysimulatorV1beta::GoogleCloudPolicysimulatorV1betaOrgPolicyViolationsPreview
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/policysimulator_v1beta/classes.rb,
lib/google/apis/policysimulator_v1beta/representations.rb,
lib/google/apis/policysimulator_v1beta/representations.rb
Overview
OrgPolicyViolationsPreview is a resource providing a preview of the violations that will exist if an OrgPolicy change is made. The list of violations are modeled as child resources and retrieved via a ListOrgPolicyViolations API call. There are potentially more OrgPolicyViolations than could fit in an embedded field. Thus, the use of a child resource instead of a field.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#custom_constraints ⇒ Array<String>
Output only.
-
#name ⇒ String
Output only.
-
#overlay ⇒ Google::Apis::PolicysimulatorV1beta::GoogleCloudPolicysimulatorV1betaOrgPolicyOverlay
The proposed changes to OrgPolicy.
-
#resource_counts ⇒ Google::Apis::PolicysimulatorV1beta::GoogleCloudPolicysimulatorV1betaOrgPolicyViolationsPreviewResourceCounts
A summary of the state of all resources scanned for compliance with the changed OrgPolicy.
-
#state ⇒ String
Output only.
-
#violations_count ⇒ Fixnum
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudPolicysimulatorV1betaOrgPolicyViolationsPreview
constructor
A new instance of GoogleCloudPolicysimulatorV1betaOrgPolicyViolationsPreview.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudPolicysimulatorV1betaOrgPolicyViolationsPreview
Returns a new instance of GoogleCloudPolicysimulatorV1betaOrgPolicyViolationsPreview.
1250 1251 1252 |
# File 'lib/google/apis/policysimulator_v1beta/classes.rb', line 1250 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Time when this OrgPolicyViolationsPreview was created.
Corresponds to the JSON property createTime
1202 1203 1204 |
# File 'lib/google/apis/policysimulator_v1beta/classes.rb', line 1202 def create_time @create_time end |
#custom_constraints ⇒ Array<String>
Output only. The names of the constraints against which all
OrgPolicyViolations were evaluated. If OrgPolicyOverlay only contains
PolicyOverlay then it contains the name of the configured custom constraint,
applicable to the specified policies. Otherwise it contains the name of the
constraint specified in CustomConstraintOverlay. Format: organizations/
organization_id/customConstraints/custom_constraint_id`Example:
organizations/123/customConstraints/custom.createOnlyE2TypeVms
Corresponds to the JSON propertycustomConstraints`
1213 1214 1215 |
# File 'lib/google/apis/policysimulator_v1beta/classes.rb', line 1213 def custom_constraints @custom_constraints end |
#name ⇒ String
Output only. The resource name of the OrgPolicyViolationsPreview. It has the
following format: organizations/organization/locations/location/
orgPolicyViolationsPreviews/orgPolicyViolationsPreview`Example:
organizations/my-example-org/locations/global/orgPolicyViolationsPreviews/
506a5f7f
Corresponds to the JSON propertyname`
1222 1223 1224 |
# File 'lib/google/apis/policysimulator_v1beta/classes.rb', line 1222 def name @name end |
#overlay ⇒ Google::Apis::PolicysimulatorV1beta::GoogleCloudPolicysimulatorV1betaOrgPolicyOverlay
The proposed changes to OrgPolicy.
Corresponds to the JSON property overlay
1227 1228 1229 |
# File 'lib/google/apis/policysimulator_v1beta/classes.rb', line 1227 def @overlay end |
#resource_counts ⇒ Google::Apis::PolicysimulatorV1beta::GoogleCloudPolicysimulatorV1betaOrgPolicyViolationsPreviewResourceCounts
A summary of the state of all resources scanned for compliance with the
changed OrgPolicy.
Corresponds to the JSON property resourceCounts
1233 1234 1235 |
# File 'lib/google/apis/policysimulator_v1beta/classes.rb', line 1233 def resource_counts @resource_counts end |
#state ⇒ String
Output only. The state of the OrgPolicyViolationsPreview.
Corresponds to the JSON property state
1238 1239 1240 |
# File 'lib/google/apis/policysimulator_v1beta/classes.rb', line 1238 def state @state end |
#violations_count ⇒ Fixnum
Output only. The number of OrgPolicyViolations in this
OrgPolicyViolationsPreview. This count may differ from resource_summary.
noncompliant_count because each OrgPolicyViolation is specific to a resource *
and* constraint. If there are multiple constraints being evaluated (i.e.
multiple policies in the overlay), a single resource may violate multiple
constraints.
Corresponds to the JSON property violationsCount
1248 1249 1250 |
# File 'lib/google/apis/policysimulator_v1beta/classes.rb', line 1248 def violations_count @violations_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1255 1256 1257 1258 1259 1260 1261 1262 1263 |
# File 'lib/google/apis/policysimulator_v1beta/classes.rb', line 1255 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @custom_constraints = args[:custom_constraints] if args.key?(:custom_constraints) @name = args[:name] if args.key?(:name) @overlay = args[:overlay] if args.key?(:overlay) @resource_counts = args[:resource_counts] if args.key?(:resource_counts) @state = args[:state] if args.key?(:state) @violations_count = args[:violations_count] if args.key?(:violations_count) end |