Class: Google::Apis::PolicysimulatorV1beta::GoogleCloudPolicysimulatorV1betaOrgPolicyViolationsPreviewResourceCounts

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/policysimulator_v1beta/classes.rb,
lib/google/apis/policysimulator_v1beta/representations.rb,
lib/google/apis/policysimulator_v1beta/representations.rb

Overview

A summary of the state of all resources scanned for compliance with the changed OrgPolicy.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudPolicysimulatorV1betaOrgPolicyViolationsPreviewResourceCounts

Returns a new instance of GoogleCloudPolicysimulatorV1betaOrgPolicyViolationsPreviewResourceCounts.



1298
1299
1300
# File 'lib/google/apis/policysimulator_v1beta/classes.rb', line 1298

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#compliantFixnum

Output only. Number of scanned resources with zero violations. Corresponds to the JSON property compliant

Returns:

  • (Fixnum)


1274
1275
1276
# File 'lib/google/apis/policysimulator_v1beta/classes.rb', line 1274

def compliant
  @compliant
end

#errorsFixnum

Output only. Number of resources that returned an error when scanned. Corresponds to the JSON property errors

Returns:

  • (Fixnum)


1279
1280
1281
# File 'lib/google/apis/policysimulator_v1beta/classes.rb', line 1279

def errors
  @errors
end

#noncompliantFixnum

Output only. Number of scanned resources with at least one violation. Corresponds to the JSON property noncompliant

Returns:

  • (Fixnum)


1284
1285
1286
# File 'lib/google/apis/policysimulator_v1beta/classes.rb', line 1284

def noncompliant
  @noncompliant
end

#scannedFixnum

Output only. Number of resources checked for compliance. Must equal: unenforced + noncompliant + compliant + error Corresponds to the JSON property scanned

Returns:

  • (Fixnum)


1290
1291
1292
# File 'lib/google/apis/policysimulator_v1beta/classes.rb', line 1290

def scanned
  @scanned
end

#unenforcedFixnum

Output only. Number of resources where the constraint was not enforced, i.e. the Policy set enforced: false for that resource. Corresponds to the JSON property unenforced

Returns:

  • (Fixnum)


1296
1297
1298
# File 'lib/google/apis/policysimulator_v1beta/classes.rb', line 1296

def unenforced
  @unenforced
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1303
1304
1305
1306
1307
1308
1309
# File 'lib/google/apis/policysimulator_v1beta/classes.rb', line 1303

def update!(**args)
  @compliant = args[:compliant] if args.key?(:compliant)
  @errors = args[:errors] if args.key?(:errors)
  @noncompliant = args[:noncompliant] if args.key?(:noncompliant)
  @scanned = args[:scanned] if args.key?(:scanned)
  @unenforced = args[:unenforced] if args.key?(:unenforced)
end