Class: Google::Apis::PolicysimulatorV1beta::GoogleCloudPolicysimulatorV1betaReplayConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/policysimulator_v1beta/classes.rb,
lib/google/apis/policysimulator_v1beta/representations.rb,
lib/google/apis/policysimulator_v1beta/representations.rb

Overview

The configuration used for a Replay.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudPolicysimulatorV1betaReplayConfig

Returns a new instance of GoogleCloudPolicysimulatorV1betaReplayConfig.



1375
1376
1377
# File 'lib/google/apis/policysimulator_v1beta/classes.rb', line 1375

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#log_sourceString

The logs to use as input for the Replay. Corresponds to the JSON property logSource

Returns:

  • (String)


1360
1361
1362
# File 'lib/google/apis/policysimulator_v1beta/classes.rb', line 1360

def log_source
  @log_source
end

#policy_overlayHash<String,Google::Apis::PolicysimulatorV1beta::GoogleIamV1Policy>

A mapping of the resources that you want to simulate policies for and the policies that you want to simulate. Keys are the full resource names for the resources. For example, //cloudresourcemanager.googleapis.com/projects/my- project. For examples of full resource names for Google Cloud services, see https://cloud.google.com/iam/help/troubleshooter/full-resource-names. Values are Policy objects representing the policies that you want to simulate. Replays automatically take into account any IAM policies inherited through the resource hierarchy, and any policies set on descendant resources. You do not need to include these policies in the policy overlay. Corresponds to the JSON property policyOverlay



1373
1374
1375
# File 'lib/google/apis/policysimulator_v1beta/classes.rb', line 1373

def policy_overlay
  @policy_overlay
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1380
1381
1382
1383
# File 'lib/google/apis/policysimulator_v1beta/classes.rb', line 1380

def update!(**args)
  @log_source = args[:log_source] if args.key?(:log_source)
  @policy_overlay = args[:policy_overlay] if args.key?(:policy_overlay)
end