Class: Google::Apis::PolicysimulatorV1beta::GoogleCloudPolicysimulatorV1betaReplayResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/policysimulator_v1beta/classes.rb,
lib/google/apis/policysimulator_v1beta/representations.rb,
lib/google/apis/policysimulator_v1beta/representations.rb

Overview

The result of replaying a single access tuple against a simulated state.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudPolicysimulatorV1betaReplayResult

Returns a new instance of GoogleCloudPolicysimulatorV1betaReplayResult.



1463
1464
1465
# File 'lib/google/apis/policysimulator_v1beta/classes.rb', line 1463

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#access_tupleGoogle::Apis::PolicysimulatorV1beta::GoogleCloudPolicysimulatorV1betaAccessTuple

Information about the principal, resource, and permission to check. Corresponds to the JSON property accessTuple



1416
1417
1418
# File 'lib/google/apis/policysimulator_v1beta/classes.rb', line 1416

def access_tuple
  @access_tuple
end

#diffGoogle::Apis::PolicysimulatorV1beta::GoogleCloudPolicysimulatorV1betaReplayDiff

The difference between the results of evaluating an access tuple under the current (baseline) policies and under the proposed (simulated) policies. This difference explains how a principal's access could change if the proposed policies were applied. Corresponds to the JSON property diff



1424
1425
1426
# File 'lib/google/apis/policysimulator_v1beta/classes.rb', line 1424

def diff
  @diff
end

#errorGoogle::Apis::PolicysimulatorV1beta::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



1434
1435
1436
# File 'lib/google/apis/policysimulator_v1beta/classes.rb', line 1434

def error
  @error
end

#last_seen_dateGoogle::Apis::PolicysimulatorV1beta::GoogleTypeDate

Represents a whole or partial calendar date, such as a birthday. The time of day and time zone are either specified elsewhere or are insignificant. The date is relative to the Gregorian Calendar. This can represent one of the following: * A full date, with non-zero year, month, and day values. * A month and day, with a zero year (for example, an anniversary). * A year on its own, with a zero month and a zero day. * A year and month, with a zero day (for example, a credit card expiration date). Related types: * google.type. TimeOfDay * google.type.DateTime * google.protobuf.Timestamp Corresponds to the JSON property lastSeenDate



1446
1447
1448
# File 'lib/google/apis/policysimulator_v1beta/classes.rb', line 1446

def last_seen_date
  @last_seen_date
end

#nameString

The resource name of the ReplayResult, in the following format: projects| folders|organizations`/`resource-id`/locations/global/replays/`replay-id`/ results/`replay-result-id, where resource-id is the ID of the project, folder, or organization that owns the Replay. Example: projects/my-example- project/locations/global/replays/506a5f7f-38ce-4d7d-8e03-479ce1833c36/results/ 1234 Corresponds to the JSON property name

Returns:

  • (String)


1456
1457
1458
# File 'lib/google/apis/policysimulator_v1beta/classes.rb', line 1456

def name
  @name
end

#parentString

The Replay that the access tuple was included in. Corresponds to the JSON property parent

Returns:

  • (String)


1461
1462
1463
# File 'lib/google/apis/policysimulator_v1beta/classes.rb', line 1461

def parent
  @parent
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1468
1469
1470
1471
1472
1473
1474
1475
# File 'lib/google/apis/policysimulator_v1beta/classes.rb', line 1468

def update!(**args)
  @access_tuple = args[:access_tuple] if args.key?(:access_tuple)
  @diff = args[:diff] if args.key?(:diff)
  @error = args[:error] if args.key?(:error)
  @last_seen_date = args[:last_seen_date] if args.key?(:last_seen_date)
  @name = args[:name] if args.key?(:name)
  @parent = args[:parent] if args.key?(:parent)
end