Class: Google::Apis::PolicysimulatorV1beta::GoogleLongrunningListOperationsResponse
- Inherits:
-
Object
- Object
- Google::Apis::PolicysimulatorV1beta::GoogleLongrunningListOperationsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/policysimulator_v1beta/classes.rb,
lib/google/apis/policysimulator_v1beta/representations.rb,
lib/google/apis/policysimulator_v1beta/representations.rb
Overview
The response message for Operations.ListOperations.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
The standard List next-page token.
-
#operations ⇒ Array<Google::Apis::PolicysimulatorV1beta::GoogleLongrunningOperation>
A list of operations that matches the specified filter in the request.
-
#unreachable ⇒ Array<String>
Unordered list.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleLongrunningListOperationsResponse
constructor
A new instance of GoogleLongrunningListOperationsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleLongrunningListOperationsResponse
Returns a new instance of GoogleLongrunningListOperationsResponse.
1875 1876 1877 |
# File 'lib/google/apis/policysimulator_v1beta/classes.rb', line 1875 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
The standard List next-page token.
Corresponds to the JSON property nextPageToken
1860 1861 1862 |
# File 'lib/google/apis/policysimulator_v1beta/classes.rb', line 1860 def next_page_token @next_page_token end |
#operations ⇒ Array<Google::Apis::PolicysimulatorV1beta::GoogleLongrunningOperation>
A list of operations that matches the specified filter in the request.
Corresponds to the JSON property operations
1865 1866 1867 |
# File 'lib/google/apis/policysimulator_v1beta/classes.rb', line 1865 def operations @operations end |
#unreachable ⇒ Array<String>
Unordered list. Unreachable resources. Populated when the request sets
ListOperationsRequest.return_partial_success and reads across collections.
For example, when attempting to list all resources across all supported
locations.
Corresponds to the JSON property unreachable
1873 1874 1875 |
# File 'lib/google/apis/policysimulator_v1beta/classes.rb', line 1873 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1880 1881 1882 1883 1884 |
# File 'lib/google/apis/policysimulator_v1beta/classes.rb', line 1880 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @operations = args[:operations] if args.key?(:operations) @unreachable = args[:unreachable] if args.key?(:unreachable) end |