Class: Google::Apis::PolicysimulatorV1beta::PolicySimulatorService
- Inherits:
-
Core::BaseService
- Object
- Core::BaseService
- Google::Apis::PolicysimulatorV1beta::PolicySimulatorService
- Defined in:
- lib/google/apis/policysimulator_v1beta/service.rb
Overview
Policy Simulator API
Policy Simulator is a collection of endpoints for creating, running, and
viewing a Replay. A Replay is a type of simulation that lets you see how
your members' access to resources might change if you changed your IAM policy.
During a Replay, Policy Simulator re-evaluates, or replays, past access
attempts under both the current policy and your proposed policy, and compares
those results to determine how your members' access might change under the
proposed policy.
Constant Summary collapse
- DEFAULT_ENDPOINT_TEMPLATE =
"https://policysimulator.$UNIVERSE_DOMAIN$/"
Instance Attribute Summary collapse
-
#key ⇒ String
API key.
-
#quota_user ⇒ String
Available to use for quota purposes for server-side applications.
Instance Method Summary collapse
-
#create_folder_location_replay(parent, google_cloud_policysimulator_v1beta_replay_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PolicysimulatorV1beta::GoogleLongrunningOperation
Creates and starts a Replay using the given ReplayConfig.
-
#create_organization_location_org_policy_violations_preview(parent, google_cloud_policysimulator_v1beta_org_policy_violations_preview_object = nil, org_policy_violations_preview_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PolicysimulatorV1beta::GoogleLongrunningOperation
CreateOrgPolicyViolationsPreview creates an OrgPolicyViolationsPreview for the proposed changes in the provided OrgPolicyViolationsPreview.OrgPolicyOverlay.
-
#create_organization_location_replay(parent, google_cloud_policysimulator_v1beta_replay_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PolicysimulatorV1beta::GoogleLongrunningOperation
Creates and starts a Replay using the given ReplayConfig.
-
#create_project_location_replay(parent, google_cloud_policysimulator_v1beta_replay_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PolicysimulatorV1beta::GoogleLongrunningOperation
Creates and starts a Replay using the given ReplayConfig.
-
#generate_organization_location_org_policy_violations_preview(parent, google_cloud_policysimulator_v1beta_org_policy_violations_preview_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PolicysimulatorV1beta::GoogleLongrunningOperation
GenerateOrgPolicyViolationsPreview generates an OrgPolicyViolationsPreview for the proposed changes in the provided OrgPolicyViolationsPreview.
-
#get_folder_location_access_policy_simulation_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PolicysimulatorV1beta::GoogleLongrunningOperation
Gets the latest state of a long-running operation.
-
#get_folder_location_org_policy_violations_preview_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PolicysimulatorV1beta::GoogleLongrunningOperation
Gets the latest state of a long-running operation.
-
#get_folder_location_replay(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PolicysimulatorV1beta::GoogleCloudPolicysimulatorV1betaReplay
Gets the specified Replay.
-
#get_folder_location_replay_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PolicysimulatorV1beta::GoogleLongrunningOperation
Gets the latest state of a long-running operation.
-
#get_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PolicysimulatorV1beta::GoogleLongrunningOperation
Gets the latest state of a long-running operation.
-
#get_organization_location_access_policy_simulation_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PolicysimulatorV1beta::GoogleLongrunningOperation
Gets the latest state of a long-running operation.
-
#get_organization_location_org_policy_violations_preview(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PolicysimulatorV1beta::GoogleCloudPolicysimulatorV1betaOrgPolicyViolationsPreview
GetOrgPolicyViolationsPreview gets the specified OrgPolicyViolationsPreview.
-
#get_organization_location_org_policy_violations_preview_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PolicysimulatorV1beta::GoogleLongrunningOperation
Gets the latest state of a long-running operation.
-
#get_organization_location_replay(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PolicysimulatorV1beta::GoogleCloudPolicysimulatorV1betaReplay
Gets the specified Replay.
-
#get_organization_location_replay_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PolicysimulatorV1beta::GoogleLongrunningOperation
Gets the latest state of a long-running operation.
-
#get_project_location_access_policy_simulation_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PolicysimulatorV1beta::GoogleLongrunningOperation
Gets the latest state of a long-running operation.
-
#get_project_location_org_policy_violations_preview_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PolicysimulatorV1beta::GoogleLongrunningOperation
Gets the latest state of a long-running operation.
-
#get_project_location_replay(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PolicysimulatorV1beta::GoogleCloudPolicysimulatorV1betaReplay
Gets the specified Replay.
-
#get_project_location_replay_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PolicysimulatorV1beta::GoogleLongrunningOperation
Gets the latest state of a long-running operation.
-
#initialize ⇒ PolicySimulatorService
constructor
A new instance of PolicySimulatorService.
-
#list_folder_location_replay_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PolicysimulatorV1beta::GoogleLongrunningListOperationsResponse
Lists operations that match the specified filter in the request.
-
#list_folder_location_replay_results(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PolicysimulatorV1beta::GoogleCloudPolicysimulatorV1betaListReplayResultsResponse
Lists the results of running a Replay.
-
#list_folder_location_replays(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PolicysimulatorV1beta::GoogleCloudPolicysimulatorV1betaListReplaysResponse
Lists each Replay in a project, folder, or organization.
-
#list_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PolicysimulatorV1beta::GoogleLongrunningListOperationsResponse
Lists operations that match the specified filter in the request.
-
#list_organization_location_org_policy_violations_preview_org_policy_violations(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PolicysimulatorV1beta::GoogleCloudPolicysimulatorV1betaListOrgPolicyViolationsResponse
ListOrgPolicyViolations lists the OrgPolicyViolations that are present in an OrgPolicyViolationsPreview.
-
#list_organization_location_org_policy_violations_previews(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PolicysimulatorV1beta::GoogleCloudPolicysimulatorV1betaListOrgPolicyViolationsPreviewsResponse
ListOrgPolicyViolationsPreviews lists each OrgPolicyViolationsPreview in an organization.
-
#list_organization_location_replay_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PolicysimulatorV1beta::GoogleLongrunningListOperationsResponse
Lists operations that match the specified filter in the request.
-
#list_organization_location_replay_results(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PolicysimulatorV1beta::GoogleCloudPolicysimulatorV1betaListReplayResultsResponse
Lists the results of running a Replay.
-
#list_organization_location_replays(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PolicysimulatorV1beta::GoogleCloudPolicysimulatorV1betaListReplaysResponse
Lists each Replay in a project, folder, or organization.
-
#list_project_location_replay_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PolicysimulatorV1beta::GoogleLongrunningListOperationsResponse
Lists operations that match the specified filter in the request.
-
#list_project_location_replay_results(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PolicysimulatorV1beta::GoogleCloudPolicysimulatorV1betaListReplayResultsResponse
Lists the results of running a Replay.
-
#list_project_location_replays(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PolicysimulatorV1beta::GoogleCloudPolicysimulatorV1betaListReplaysResponse
Lists each Replay in a project, folder, or organization.
Constructor Details
#initialize ⇒ PolicySimulatorService
Returns a new instance of PolicySimulatorService.
53 54 55 56 57 58 |
# File 'lib/google/apis/policysimulator_v1beta/service.rb', line 53 def initialize super(DEFAULT_ENDPOINT_TEMPLATE, '', client_name: 'google-apis-policysimulator_v1beta', client_version: Google::Apis::PolicysimulatorV1beta::GEM_VERSION) @batch_path = 'batch' end |
Instance Attribute Details
#key ⇒ String
Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
46 47 48 |
# File 'lib/google/apis/policysimulator_v1beta/service.rb', line 46 def key @key end |
#quota_user ⇒ String
Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
51 52 53 |
# File 'lib/google/apis/policysimulator_v1beta/service.rb', line 51 def quota_user @quota_user end |
Instance Method Details
#create_folder_location_replay(parent, google_cloud_policysimulator_v1beta_replay_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PolicysimulatorV1beta::GoogleLongrunningOperation
Creates and starts a Replay using the given ReplayConfig.
145 146 147 148 149 150 151 152 153 154 155 |
# File 'lib/google/apis/policysimulator_v1beta/service.rb', line 145 def create_folder_location_replay(parent, google_cloud_policysimulator_v1beta_replay_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta/{+parent}/replays', ) command.request_representation = Google::Apis::PolicysimulatorV1beta::GoogleCloudPolicysimulatorV1betaReplay::Representation command.request_object = google_cloud_policysimulator_v1beta_replay_object command.response_representation = Google::Apis::PolicysimulatorV1beta::GoogleLongrunningOperation::Representation command.response_class = Google::Apis::PolicysimulatorV1beta::GoogleLongrunningOperation command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_organization_location_org_policy_violations_preview(parent, google_cloud_policysimulator_v1beta_org_policy_violations_preview_object = nil, org_policy_violations_preview_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PolicysimulatorV1beta::GoogleLongrunningOperation
CreateOrgPolicyViolationsPreview creates an OrgPolicyViolationsPreview for the
proposed changes in the provided OrgPolicyViolationsPreview.OrgPolicyOverlay.
The changes to OrgPolicy are specified by this OrgPolicyOverlay. The
resources to scan are inferred from these specified changes.
500 501 502 503 504 505 506 507 508 509 510 511 |
# File 'lib/google/apis/policysimulator_v1beta/service.rb', line 500 def create_organization_location_org_policy_violations_preview(parent, google_cloud_policysimulator_v1beta_org_policy_violations_preview_object = nil, org_policy_violations_preview_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta/{+parent}/orgPolicyViolationsPreviews', ) command.request_representation = Google::Apis::PolicysimulatorV1beta::GoogleCloudPolicysimulatorV1betaOrgPolicyViolationsPreview::Representation command.request_object = google_cloud_policysimulator_v1beta_org_policy_violations_preview_object command.response_representation = Google::Apis::PolicysimulatorV1beta::GoogleLongrunningOperation::Representation command.response_class = Google::Apis::PolicysimulatorV1beta::GoogleLongrunningOperation command.params['parent'] = parent unless parent.nil? command.query['orgPolicyViolationsPreviewId'] = org_policy_violations_preview_id unless org_policy_violations_preview_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_organization_location_replay(parent, google_cloud_policysimulator_v1beta_replay_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PolicysimulatorV1beta::GoogleLongrunningOperation
Creates and starts a Replay using the given ReplayConfig.
722 723 724 725 726 727 728 729 730 731 732 |
# File 'lib/google/apis/policysimulator_v1beta/service.rb', line 722 def create_organization_location_replay(parent, google_cloud_policysimulator_v1beta_replay_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta/{+parent}/replays', ) command.request_representation = Google::Apis::PolicysimulatorV1beta::GoogleCloudPolicysimulatorV1betaReplay::Representation command.request_object = google_cloud_policysimulator_v1beta_replay_object command.response_representation = Google::Apis::PolicysimulatorV1beta::GoogleLongrunningOperation::Representation command.response_class = Google::Apis::PolicysimulatorV1beta::GoogleLongrunningOperation command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_replay(parent, google_cloud_policysimulator_v1beta_replay_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PolicysimulatorV1beta::GoogleLongrunningOperation
Creates and starts a Replay using the given ReplayConfig.
1023 1024 1025 1026 1027 1028 1029 1030 1031 1032 1033 |
# File 'lib/google/apis/policysimulator_v1beta/service.rb', line 1023 def create_project_location_replay(parent, google_cloud_policysimulator_v1beta_replay_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta/{+parent}/replays', ) command.request_representation = Google::Apis::PolicysimulatorV1beta::GoogleCloudPolicysimulatorV1betaReplay::Representation command.request_object = google_cloud_policysimulator_v1beta_replay_object command.response_representation = Google::Apis::PolicysimulatorV1beta::GoogleLongrunningOperation::Representation command.response_class = Google::Apis::PolicysimulatorV1beta::GoogleLongrunningOperation command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#generate_organization_location_org_policy_violations_preview(parent, google_cloud_policysimulator_v1beta_org_policy_violations_preview_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PolicysimulatorV1beta::GoogleLongrunningOperation
GenerateOrgPolicyViolationsPreview generates an OrgPolicyViolationsPreview for
the proposed changes in the provided OrgPolicyViolationsPreview.
OrgPolicyOverlay. The changes to OrgPolicy are specified by this
OrgPolicyOverlay. The resources to scan are inferred from these specified
changes.
539 540 541 542 543 544 545 546 547 548 549 |
# File 'lib/google/apis/policysimulator_v1beta/service.rb', line 539 def generate_organization_location_org_policy_violations_preview(parent, google_cloud_policysimulator_v1beta_org_policy_violations_preview_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta/{+parent}/orgPolicyViolationsPreviews:generate', ) command.request_representation = Google::Apis::PolicysimulatorV1beta::GoogleCloudPolicysimulatorV1betaOrgPolicyViolationsPreview::Representation command.request_object = google_cloud_policysimulator_v1beta_org_policy_violations_preview_object command.response_representation = Google::Apis::PolicysimulatorV1beta::GoogleLongrunningOperation::Representation command.response_class = Google::Apis::PolicysimulatorV1beta::GoogleLongrunningOperation command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_folder_location_access_policy_simulation_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PolicysimulatorV1beta::GoogleLongrunningOperation
Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
81 82 83 84 85 86 87 88 89 |
# File 'lib/google/apis/policysimulator_v1beta/service.rb', line 81 def get_folder_location_access_policy_simulation_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta/{+name}', ) command.response_representation = Google::Apis::PolicysimulatorV1beta::GoogleLongrunningOperation::Representation command.response_class = Google::Apis::PolicysimulatorV1beta::GoogleLongrunningOperation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_folder_location_org_policy_violations_preview_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PolicysimulatorV1beta::GoogleLongrunningOperation
Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
112 113 114 115 116 117 118 119 120 |
# File 'lib/google/apis/policysimulator_v1beta/service.rb', line 112 def get_folder_location_org_policy_violations_preview_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta/{+name}', ) command.response_representation = Google::Apis::PolicysimulatorV1beta::GoogleLongrunningOperation::Representation command.response_class = Google::Apis::PolicysimulatorV1beta::GoogleLongrunningOperation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_folder_location_replay(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PolicysimulatorV1beta::GoogleCloudPolicysimulatorV1betaReplay
Gets the specified Replay. Each Replay is available for at least 7 days.
181 182 183 184 185 186 187 188 189 |
# File 'lib/google/apis/policysimulator_v1beta/service.rb', line 181 def get_folder_location_replay(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta/{+name}', ) command.response_representation = Google::Apis::PolicysimulatorV1beta::GoogleCloudPolicysimulatorV1betaReplay::Representation command.response_class = Google::Apis::PolicysimulatorV1beta::GoogleCloudPolicysimulatorV1betaReplay command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_folder_location_replay_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PolicysimulatorV1beta::GoogleLongrunningOperation
Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
259 260 261 262 263 264 265 266 267 |
# File 'lib/google/apis/policysimulator_v1beta/service.rb', line 259 def get_folder_location_replay_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta/{+name}', ) command.response_representation = Google::Apis::PolicysimulatorV1beta::GoogleLongrunningOperation::Representation command.response_class = Google::Apis::PolicysimulatorV1beta::GoogleLongrunningOperation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PolicysimulatorV1beta::GoogleLongrunningOperation
Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
382 383 384 385 386 387 388 389 390 |
# File 'lib/google/apis/policysimulator_v1beta/service.rb', line 382 def get_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta/{+name}', ) command.response_representation = Google::Apis::PolicysimulatorV1beta::GoogleLongrunningOperation::Representation command.response_class = Google::Apis::PolicysimulatorV1beta::GoogleLongrunningOperation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_organization_location_access_policy_simulation_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PolicysimulatorV1beta::GoogleLongrunningOperation
Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
462 463 464 465 466 467 468 469 470 |
# File 'lib/google/apis/policysimulator_v1beta/service.rb', line 462 def get_organization_location_access_policy_simulation_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta/{+name}', ) command.response_representation = Google::Apis::PolicysimulatorV1beta::GoogleLongrunningOperation::Representation command.response_class = Google::Apis::PolicysimulatorV1beta::GoogleLongrunningOperation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_organization_location_org_policy_violations_preview(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PolicysimulatorV1beta::GoogleCloudPolicysimulatorV1betaOrgPolicyViolationsPreview
GetOrgPolicyViolationsPreview gets the specified OrgPolicyViolationsPreview. Each OrgPolicyViolationsPreview is available for at least 7 days.
572 573 574 575 576 577 578 579 580 |
# File 'lib/google/apis/policysimulator_v1beta/service.rb', line 572 def get_organization_location_org_policy_violations_preview(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta/{+name}', ) command.response_representation = Google::Apis::PolicysimulatorV1beta::GoogleCloudPolicysimulatorV1betaOrgPolicyViolationsPreview::Representation command.response_class = Google::Apis::PolicysimulatorV1beta::GoogleCloudPolicysimulatorV1betaOrgPolicyViolationsPreview command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_organization_location_org_policy_violations_preview_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PolicysimulatorV1beta::GoogleLongrunningOperation
Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
646 647 648 649 650 651 652 653 654 |
# File 'lib/google/apis/policysimulator_v1beta/service.rb', line 646 def get_organization_location_org_policy_violations_preview_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta/{+name}', ) command.response_representation = Google::Apis::PolicysimulatorV1beta::GoogleLongrunningOperation::Representation command.response_class = Google::Apis::PolicysimulatorV1beta::GoogleLongrunningOperation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_organization_location_replay(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PolicysimulatorV1beta::GoogleCloudPolicysimulatorV1betaReplay
Gets the specified Replay. Each Replay is available for at least 7 days.
758 759 760 761 762 763 764 765 766 |
# File 'lib/google/apis/policysimulator_v1beta/service.rb', line 758 def get_organization_location_replay(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta/{+name}', ) command.response_representation = Google::Apis::PolicysimulatorV1beta::GoogleCloudPolicysimulatorV1betaReplay::Representation command.response_class = Google::Apis::PolicysimulatorV1beta::GoogleCloudPolicysimulatorV1betaReplay command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_organization_location_replay_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PolicysimulatorV1beta::GoogleLongrunningOperation
Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
836 837 838 839 840 841 842 843 844 |
# File 'lib/google/apis/policysimulator_v1beta/service.rb', line 836 def get_organization_location_replay_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta/{+name}', ) command.response_representation = Google::Apis::PolicysimulatorV1beta::GoogleLongrunningOperation::Representation command.response_class = Google::Apis::PolicysimulatorV1beta::GoogleLongrunningOperation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_access_policy_simulation_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PolicysimulatorV1beta::GoogleLongrunningOperation
Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
959 960 961 962 963 964 965 966 967 |
# File 'lib/google/apis/policysimulator_v1beta/service.rb', line 959 def get_project_location_access_policy_simulation_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta/{+name}', ) command.response_representation = Google::Apis::PolicysimulatorV1beta::GoogleLongrunningOperation::Representation command.response_class = Google::Apis::PolicysimulatorV1beta::GoogleLongrunningOperation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_org_policy_violations_preview_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PolicysimulatorV1beta::GoogleLongrunningOperation
Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
990 991 992 993 994 995 996 997 998 |
# File 'lib/google/apis/policysimulator_v1beta/service.rb', line 990 def get_project_location_org_policy_violations_preview_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta/{+name}', ) command.response_representation = Google::Apis::PolicysimulatorV1beta::GoogleLongrunningOperation::Representation command.response_class = Google::Apis::PolicysimulatorV1beta::GoogleLongrunningOperation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_replay(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PolicysimulatorV1beta::GoogleCloudPolicysimulatorV1betaReplay
Gets the specified Replay. Each Replay is available for at least 7 days.
1059 1060 1061 1062 1063 1064 1065 1066 1067 |
# File 'lib/google/apis/policysimulator_v1beta/service.rb', line 1059 def get_project_location_replay(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta/{+name}', ) command.response_representation = Google::Apis::PolicysimulatorV1beta::GoogleCloudPolicysimulatorV1betaReplay::Representation command.response_class = Google::Apis::PolicysimulatorV1beta::GoogleCloudPolicysimulatorV1betaReplay command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_replay_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PolicysimulatorV1beta::GoogleLongrunningOperation
Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
1137 1138 1139 1140 1141 1142 1143 1144 1145 |
# File 'lib/google/apis/policysimulator_v1beta/service.rb', line 1137 def get_project_location_replay_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta/{+name}', ) command.response_representation = Google::Apis::PolicysimulatorV1beta::GoogleLongrunningOperation::Representation command.response_class = Google::Apis::PolicysimulatorV1beta::GoogleLongrunningOperation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_folder_location_replay_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PolicysimulatorV1beta::GoogleLongrunningListOperationsResponse
Lists operations that match the specified filter in the request. If the server
doesn't support this method, it returns UNIMPLEMENTED.
304 305 306 307 308 309 310 311 312 313 314 315 316 |
# File 'lib/google/apis/policysimulator_v1beta/service.rb', line 304 def list_folder_location_replay_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta/{+name}', ) command.response_representation = Google::Apis::PolicysimulatorV1beta::GoogleLongrunningListOperationsResponse::Representation command.response_class = Google::Apis::PolicysimulatorV1beta::GoogleLongrunningListOperationsResponse command.params['name'] = name unless name.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['returnPartialSuccess'] = return_partial_success unless return_partial_success.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_folder_location_replay_results(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PolicysimulatorV1beta::GoogleCloudPolicysimulatorV1betaListReplayResultsResponse
Lists the results of running a Replay.
349 350 351 352 353 354 355 356 357 358 359 |
# File 'lib/google/apis/policysimulator_v1beta/service.rb', line 349 def list_folder_location_replay_results(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta/{+parent}/results', ) command.response_representation = Google::Apis::PolicysimulatorV1beta::GoogleCloudPolicysimulatorV1betaListReplayResultsResponse::Representation command.response_class = Google::Apis::PolicysimulatorV1beta::GoogleCloudPolicysimulatorV1betaListReplayResultsResponse command.params['parent'] = parent unless parent.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_folder_location_replays(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PolicysimulatorV1beta::GoogleCloudPolicysimulatorV1betaListReplaysResponse
Lists each Replay in a project, folder, or organization. Each Replay is
available for at least 7 days.
226 227 228 229 230 231 232 233 234 235 236 |
# File 'lib/google/apis/policysimulator_v1beta/service.rb', line 226 def list_folder_location_replays(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta/{+parent}/replays', ) command.response_representation = Google::Apis::PolicysimulatorV1beta::GoogleCloudPolicysimulatorV1betaListReplaysResponse::Representation command.response_class = Google::Apis::PolicysimulatorV1beta::GoogleCloudPolicysimulatorV1betaListReplaysResponse command.params['parent'] = parent unless parent.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PolicysimulatorV1beta::GoogleLongrunningListOperationsResponse
Lists operations that match the specified filter in the request. If the server
doesn't support this method, it returns UNIMPLEMENTED.
427 428 429 430 431 432 433 434 435 436 437 438 439 |
# File 'lib/google/apis/policysimulator_v1beta/service.rb', line 427 def list_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta/{+name}', ) command.response_representation = Google::Apis::PolicysimulatorV1beta::GoogleLongrunningListOperationsResponse::Representation command.response_class = Google::Apis::PolicysimulatorV1beta::GoogleLongrunningListOperationsResponse command.params['name'] = name unless name.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['returnPartialSuccess'] = return_partial_success unless return_partial_success.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_organization_location_org_policy_violations_preview_org_policy_violations(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PolicysimulatorV1beta::GoogleCloudPolicysimulatorV1betaListOrgPolicyViolationsResponse
ListOrgPolicyViolations lists the OrgPolicyViolations that are present in an OrgPolicyViolationsPreview.
687 688 689 690 691 692 693 694 695 696 697 |
# File 'lib/google/apis/policysimulator_v1beta/service.rb', line 687 def list_organization_location_org_policy_violations_preview_org_policy_violations(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta/{+parent}/orgPolicyViolations', ) command.response_representation = Google::Apis::PolicysimulatorV1beta::GoogleCloudPolicysimulatorV1betaListOrgPolicyViolationsResponse::Representation command.response_class = Google::Apis::PolicysimulatorV1beta::GoogleCloudPolicysimulatorV1betaListOrgPolicyViolationsResponse command.params['parent'] = parent unless parent.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_organization_location_org_policy_violations_previews(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PolicysimulatorV1beta::GoogleCloudPolicysimulatorV1betaListOrgPolicyViolationsPreviewsResponse
ListOrgPolicyViolationsPreviews lists each OrgPolicyViolationsPreview in an organization. Each OrgPolicyViolationsPreview is available for at least 7 days.
613 614 615 616 617 618 619 620 621 622 623 |
# File 'lib/google/apis/policysimulator_v1beta/service.rb', line 613 def list_organization_location_org_policy_violations_previews(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta/{+parent}/orgPolicyViolationsPreviews', ) command.response_representation = Google::Apis::PolicysimulatorV1beta::GoogleCloudPolicysimulatorV1betaListOrgPolicyViolationsPreviewsResponse::Representation command.response_class = Google::Apis::PolicysimulatorV1beta::GoogleCloudPolicysimulatorV1betaListOrgPolicyViolationsPreviewsResponse command.params['parent'] = parent unless parent.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_organization_location_replay_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PolicysimulatorV1beta::GoogleLongrunningListOperationsResponse
Lists operations that match the specified filter in the request. If the server
doesn't support this method, it returns UNIMPLEMENTED.
881 882 883 884 885 886 887 888 889 890 891 892 893 |
# File 'lib/google/apis/policysimulator_v1beta/service.rb', line 881 def list_organization_location_replay_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta/{+name}', ) command.response_representation = Google::Apis::PolicysimulatorV1beta::GoogleLongrunningListOperationsResponse::Representation command.response_class = Google::Apis::PolicysimulatorV1beta::GoogleLongrunningListOperationsResponse command.params['name'] = name unless name.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['returnPartialSuccess'] = return_partial_success unless return_partial_success.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_organization_location_replay_results(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PolicysimulatorV1beta::GoogleCloudPolicysimulatorV1betaListReplayResultsResponse
Lists the results of running a Replay.
926 927 928 929 930 931 932 933 934 935 936 |
# File 'lib/google/apis/policysimulator_v1beta/service.rb', line 926 def list_organization_location_replay_results(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta/{+parent}/results', ) command.response_representation = Google::Apis::PolicysimulatorV1beta::GoogleCloudPolicysimulatorV1betaListReplayResultsResponse::Representation command.response_class = Google::Apis::PolicysimulatorV1beta::GoogleCloudPolicysimulatorV1betaListReplayResultsResponse command.params['parent'] = parent unless parent.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_organization_location_replays(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PolicysimulatorV1beta::GoogleCloudPolicysimulatorV1betaListReplaysResponse
Lists each Replay in a project, folder, or organization. Each Replay is
available for at least 7 days.
803 804 805 806 807 808 809 810 811 812 813 |
# File 'lib/google/apis/policysimulator_v1beta/service.rb', line 803 def list_organization_location_replays(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta/{+parent}/replays', ) command.response_representation = Google::Apis::PolicysimulatorV1beta::GoogleCloudPolicysimulatorV1betaListReplaysResponse::Representation command.response_class = Google::Apis::PolicysimulatorV1beta::GoogleCloudPolicysimulatorV1betaListReplaysResponse command.params['parent'] = parent unless parent.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_replay_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PolicysimulatorV1beta::GoogleLongrunningListOperationsResponse
Lists operations that match the specified filter in the request. If the server
doesn't support this method, it returns UNIMPLEMENTED.
1182 1183 1184 1185 1186 1187 1188 1189 1190 1191 1192 1193 1194 |
# File 'lib/google/apis/policysimulator_v1beta/service.rb', line 1182 def list_project_location_replay_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta/{+name}', ) command.response_representation = Google::Apis::PolicysimulatorV1beta::GoogleLongrunningListOperationsResponse::Representation command.response_class = Google::Apis::PolicysimulatorV1beta::GoogleLongrunningListOperationsResponse command.params['name'] = name unless name.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['returnPartialSuccess'] = return_partial_success unless return_partial_success.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_replay_results(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PolicysimulatorV1beta::GoogleCloudPolicysimulatorV1betaListReplayResultsResponse
Lists the results of running a Replay.
1227 1228 1229 1230 1231 1232 1233 1234 1235 1236 1237 |
# File 'lib/google/apis/policysimulator_v1beta/service.rb', line 1227 def list_project_location_replay_results(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta/{+parent}/results', ) command.response_representation = Google::Apis::PolicysimulatorV1beta::GoogleCloudPolicysimulatorV1betaListReplayResultsResponse::Representation command.response_class = Google::Apis::PolicysimulatorV1beta::GoogleCloudPolicysimulatorV1betaListReplayResultsResponse command.params['parent'] = parent unless parent.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_replays(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PolicysimulatorV1beta::GoogleCloudPolicysimulatorV1betaListReplaysResponse
Lists each Replay in a project, folder, or organization. Each Replay is
available for at least 7 days.
1104 1105 1106 1107 1108 1109 1110 1111 1112 1113 1114 |
# File 'lib/google/apis/policysimulator_v1beta/service.rb', line 1104 def list_project_location_replays(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta/{+parent}/replays', ) command.response_representation = Google::Apis::PolicysimulatorV1beta::GoogleCloudPolicysimulatorV1betaListReplaysResponse::Representation command.response_class = Google::Apis::PolicysimulatorV1beta::GoogleCloudPolicysimulatorV1betaListReplaysResponse command.params['parent'] = parent unless parent.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |