Class: Google::Apis::PolicysimulatorV1beta::GoogleCloudPolicysimulatorV1betaOrgPolicyViolation
- Inherits:
-
Object
- Object
- Google::Apis::PolicysimulatorV1beta::GoogleCloudPolicysimulatorV1betaOrgPolicyViolation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/policysimulator_v1beta/classes.rb,
lib/google/apis/policysimulator_v1beta/representations.rb,
lib/google/apis/policysimulator_v1beta/representations.rb
Overview
OrgPolicyViolation is a resource representing a single resource violating a single OrgPolicy constraint.
Instance Attribute Summary collapse
-
#custom_constraint ⇒ Google::Apis::PolicysimulatorV1beta::GoogleCloudOrgpolicyV2CustomConstraint
A custom constraint defined by customers which can only be applied to the given resource types and organization.
-
#error ⇒ Google::Apis::PolicysimulatorV1beta::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#name ⇒ String
The name of the
OrgPolicyViolation. -
#resource ⇒ Google::Apis::PolicysimulatorV1beta::GoogleCloudPolicysimulatorV1betaResourceContext
ResourceContext provides the context we know about a resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudPolicysimulatorV1betaOrgPolicyViolation
constructor
A new instance of GoogleCloudPolicysimulatorV1betaOrgPolicyViolation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudPolicysimulatorV1betaOrgPolicyViolation
Returns a new instance of GoogleCloudPolicysimulatorV1betaOrgPolicyViolation.
1178 1179 1180 |
# File 'lib/google/apis/policysimulator_v1beta/classes.rb', line 1178 def initialize(**args) update!(**args) end |
Instance Attribute Details
#custom_constraint ⇒ Google::Apis::PolicysimulatorV1beta::GoogleCloudOrgpolicyV2CustomConstraint
A custom constraint defined by customers which can only be applied to the
given resource types and organization. By creating a custom constraint,
customers can apply policies of this custom constraint. Creating a custom
constraint itself does NOT apply any policy enforcement.
Corresponds to the JSON property customConstraint
1153 1154 1155 |
# File 'lib/google/apis/policysimulator_v1beta/classes.rb', line 1153 def custom_constraint @custom_constraint end |
#error ⇒ Google::Apis::PolicysimulatorV1beta::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property error
1163 1164 1165 |
# File 'lib/google/apis/policysimulator_v1beta/classes.rb', line 1163 def error @error end |
#name ⇒ String
The name of the OrgPolicyViolation. Example: organizations/my-example-org/
locations/global/orgPolicyViolationsPreviews/506a5f7f/orgPolicyViolations/38ce
Corresponds to the JSON propertyname`
1169 1170 1171 |
# File 'lib/google/apis/policysimulator_v1beta/classes.rb', line 1169 def name @name end |
#resource ⇒ Google::Apis::PolicysimulatorV1beta::GoogleCloudPolicysimulatorV1betaResourceContext
ResourceContext provides the context we know about a resource. It is similar
in concept to google.cloud.asset.v1.Resource, but focuses on the information
specifically used by Simulator.
Corresponds to the JSON property resource
1176 1177 1178 |
# File 'lib/google/apis/policysimulator_v1beta/classes.rb', line 1176 def resource @resource end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1183 1184 1185 1186 1187 1188 |
# File 'lib/google/apis/policysimulator_v1beta/classes.rb', line 1183 def update!(**args) @custom_constraint = args[:custom_constraint] if args.key?(:custom_constraint) @error = args[:error] if args.key?(:error) @name = args[:name] if args.key?(:name) @resource = args[:resource] if args.key?(:resource) end |